@@ -12,7 +12,7 @@ __all__ = ('BaseDashboardLayout', 'BaseDashboardPlaceholder', 'BaseDashboardPlug
 import uuid
 import json
 
-from six import text_type
+from six import text_type, PY3
 
 from django.forms import ModelForm
 from django.forms.util import ErrorList
@@ -35,7 +35,10 @@ class DashboardPluginFormBase(object):
     """
     Not a form actually. Defined for magic only.
 
-    :property iterable plugin_data_fields: Fields to get when calling the ``get_plugin_data`` method.
+    :property iterable plugin_data_fields: Fields to get when calling the ``get_plugin_data`` method. These
+        field will be JSON serialized. All other fields, even if they are part of the form, won't be.
+        Make sure all fields are serializable. If some of them aren't, override the ``save_plugin_data``
+        method and make them serializable there. See `dash.contrib.plugins.image.forms` as a good example.
 
     :example:
 
@@ -955,8 +958,8 @@ class BaseDashboardPlugin(object):
     def delete_plugin_data(self):
         """
         Used in ``dash.views.delete_dashboard_entry``. Fired automatically, when ``dash.models.DashboardEntry``
-        object is about to be deleted. Make use of it if your plugin creates database records that are not
-        monitored externally but by dash only.
+        object is about to be deleted. Make use of it if your plugin creates database records or files that are
+        not monitored externally but by dash only.
         """
 
     def pre_processor(self):
@@ -1259,7 +1262,11 @@ def get_registered_plugins():
     registered_plugins = []
 
     for uid, plugin in plugin_registry._registry.items():
-        registered_plugins.append((uid, force_text(plugin.name)))
+        if PY3:
+            plugin_name = force_text(plugin.name, encoding='utf-8')
+        else:
+            plugin_name = force_text(plugin.name, encoding='utf-8').encode('utf-8')
+        registered_plugins.append((uid, plugin_name))
 
     return registered_plugins
 
@@ -1305,7 +1312,11 @@ def get_registered_layouts():
     registered_layouts = []
 
     for uid, layout in layout_registry._registry.items():
-        registered_layouts.append((uid, force_text(layout.name)))
+        if PY3:
+            layout_name = force_text(layout.name, encoding='utf-8')
+        else:
+            layout_name = force_text(layout.name, encoding='utf-8').encode('utf-8')
+        registered_layouts.append((uid, layout_name))
 
     return registered_layouts
 
